<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.1">
<context>
    <name>BMHandler</name>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="16"/>
        <source>Disk Format Error: Please reformat it or disable &quot;Auto scan USB storage devices&quot; in Security Center</source>
        <translation>Помилка форматування диска: будь ласка, виконайте повторне форматування або вимкніть пункт «Автоматичне сканування пристроїв зберігання даних USB» у Центрі безпеки</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="19"/>
        <source>Disk Format Error: Please reformat it</source>
        <translation>Помилка форматування диска. Будь ласка, виконайте його повторне форматування.</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="24"/>
        <source>Insufficient disk Space: Ensure that the disk has enough free space</source>
        <translation>Недостатньо місця на диску: будь ласка, переконайтесь, що на диску достатньо вільного місця</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="27"/>
        <source>Disk Mount Error: Insert the disk again or reboot to retry</source>
        <translation>Помилка монтування диску: Будь ласка, знову підключіть диск або перезавантажте систему, щоб повторити спробу</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="30"/>
        <source>Image Decompression Error: Verify md5 checksum of the image to ensure its integrity</source>
        <translation>Помилка розпакування образу: Будь ласка, перевірте контрольну суму md5 образу, щоб забезпечити його цілісність</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="33"/>
        <source>Internal Error</source>
        <translation>Внутрішня помилка</translation>
    </message>
</context>
<context>
    <name>BMWindow</name>
    <message>
        <location filename="../app/bmwindow.cpp" line="79"/>
        <source>Boot Maker is a simple tool to write system image files into USB flash drives and other media.</source>
        <translation>Boot Maker — це простий інструмент для запису файлів образів систем на флеш-пам&apos;ять USB та інші носії даних.</translation>
    </message>
    <message>
        <location filename="../app/bmwindow.cpp" line="81"/>
        <source>Boot Maker</source>
        <translation>Створення дисків</translation>
    </message>
</context>
<context>
    <name>ISOSelectView</name>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="116"/>
        <source>Drag an ISO image file here</source>
        <translation>Сюди можна перетягнути файл образу ISO</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="125"/>
        <source>OR</source>
        <translation>АБО</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="82"/>
        <location filename="../app/view/isoselectview.cpp" line="140"/>
        <source>Select an ISO image file</source>
        <translation>Виберіть ISO-файл образу диску</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="170"/>
        <source>Next</source>
        <translation>Далі</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="225"/>
        <source>Reselect an ISO image file</source>
        <translation>Повторно виберіть файл образу ISO</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="188"/>
        <source>Illegal ISO image file</source>
        <translation>Некоректний файл образу ISO</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="328"/>
        <source>Detecting ISO file, please wait...</source>
        <translation>Обробляємо дані файла ISO. Будь ласка, зачекайте…</translation>
    </message>
</context>
<context>
    <name>ProgressView</name>
    <message>
        <location filename="../app/view/progressview.cpp" line="51"/>
        <source>Burning</source>
        <translation>Записуємо</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="63"/>
        <source>Burning, please wait...</source>
        <translation>Записуємо дані. Будь ласка, зачекайте…</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="71"/>
        <source>Do not remove the disk or shut down the computer during the process</source>
        <translation>Не виймайте диск і не вимикайте комп&apos;ютер під час процесу.</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="85"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Скасувати</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../libdbm/util/deviceinfo.h" line="40"/>
        <source>Removable Disk</source>
        <translation>Знімний диск</translation>
    </message>
    <message>
        <location filename="../libdbm/util/utils.cpp" line="224"/>
        <location filename="../libdbm/util/utils.cpp" line="370"/>
        <source>Removable disk</source>
        <translation>Знімний диск</translation>
    </message>
    <message>
        <location filename="../app/main.cpp" line="122"/>
        <source>Boot Maker</source>
        <translation>Створення дисків</translation>
    </message>
</context>
<context>
    <name>ResultView</name>
    <message>
        <location filename="../app/view/resultview.cpp" line="104"/>
        <source>Reboot now</source>
        <translation>Перезавантажити зараз</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="56"/>
        <source>Successful</source>
        <translation>Успішно</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="95"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>Готово</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="169"/>
        <source>The error log will be uploaded automatically with the feedback. We cannot improve without your feedback</source>
        <translation>Журнал помилок буде завантажено автоматично з відгуками. Ми не можемо покращити без вашого відгуку</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="170"/>
        <source>Submit Feedback</source>
        <translation>Надіслати Відгук</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="193"/>
        <source>After-Sale Services</source>
        <translation>Післяпродажне обслуговування</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="206"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>Закрити</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="214"/>
        <source>Sorry, process failed</source>
        <translation>Вибачте, не вдалося виконати</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="215"/>
        <source>Process failed</source>
        <translation>Помилка під час виконання</translation>
    </message>
</context>
<context>
    <name>UnmountUsbView</name>
    <message>
        <location filename="../app/view/unmountusbview.cpp" line="13"/>
        <source>Verifying data and safely removing the media, please wait...</source>
        <translation>Перевіряємо дані і безпечно вилучаємо носій із системи. Будь ласка, зачекайте…</translation>
    </message>
</context>
<context>
    <name>UsbSelectView</name>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="92"/>
        <source>Select a partition</source>
        <translation>Виберіть розділ</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="117"/>
        <source>Format the partition</source>
        <translation>Форматувати розділ</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="170"/>
        <source>Start</source>
        <translation>Почати</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="231"/>
        <source>Formatting will erase all data on the partition, but can increase the success rate, please confirm before proceeding</source>
        <translation>Форматування знищить усі дані на розділі, але може підвищити ймовірність успішного користування розділом. Будь ласка, підтвердьте дію.</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="377"/>
        <location filename="../app/view/usbselectview.cpp" line="388"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Гаразд</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="380"/>
        <source>You have selected the ISO image in this USB flash drive. Formatting it will erase all your files. Please reselect the image file or cancel the formatting.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="384"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Скасувати</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="391"/>
        <source>Formatting the partition will overwrite all data, please have a backup before proceeding.</source>
        <translation>Форматування розділу призведе до перезапису усіх даних. Будь ласка, створіть резервну копію важливих даних, перш ніж продовжувати.</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="407"/>
        <source>Disk Format Error: Please format the partition with FAT32</source>
        <translation>Помилка форматування диска: будь ласка, форматуйте розділ у FAT32</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="153"/>
        <source>No disk available</source>
        <translation>Немає доступних дисків</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="174"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>Назад</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="358"/>
        <source>Format Partition</source>
        <translation>Форматувати розділ</translation>
    </message>
</context>
</TS>